@@ -1,5 +1,5 @@
 package HTTP::Thin::UserAgent;
-$HTTP::Thin::UserAgent::VERSION = '0.015';
+$HTTP::Thin::UserAgent::VERSION = '0.016';
 use 5.12.1;
 use warnings;
 
@@ -36,49 +36,6 @@ use warnings;
                 HTTP::Thin::UserAgent::HTTPExceptionWithResponse
             );
         }
-
-        # A PR for this has been sent to HTTP::Throwable when that ships we can bump the dep
-        # and remove this method
-        sub ident_for_status_code {
-            my ($self, $code) = @_;
-
-            my %lookup = (
-                300 => 'MultipleChoices',
-                301 => 'MovedPermanently',
-                302 => 'Found',
-                303 => 'SeeOther',
-                304 => 'NotModified',
-                305 => 'UseProxy',
-                307 => 'TemporaryRedirect',
-
-                400 => 'BadRequest',
-                401 => 'Unauthorized',
-                403 => 'Forbidden',
-                404 => 'NotFound',
-                405 => 'MethodNotAllowed',
-                406 => 'NotAcceptable',
-                407 => 'ProxyAuthenticationRequired',
-                408 => 'RequestTimeout',
-                409 => 'Conflict',
-                410 => 'Gone',
-                411 => 'LengthRequired',
-                412 => 'PreconditionFailed',
-                413 => 'RequestEntityTooLarge',
-                414 => 'RequestURITooLong',
-                415 => 'UnsupportedMediaType',
-                416 => 'RequestedRangeNotSatisfiable',
-                417 => 'ExpectationFailed',
-
-                500 => 'InternalServerError',
-                501 => 'NotImplemented',
-                502 => 'BadGateway',
-                503 => 'Status::ServiceUnavailable',
-                504 => 'GatewayTimeout',
-                505 => 'HTTPVersionNotSupported',
-            );
-
-            return $lookup{$code};
-        }
 }
 
 {
@@ -111,7 +68,7 @@ use warnings;
 
     has on_error => (
         is      => 'rw',
-        default => sub { sub { confess $_->message } },
+        default => sub { sub { confess "$_" } },
         chained => 1,
     );
 
@@ -148,15 +105,15 @@ use warnings;
 
         if ( $res->is_error ) {
             my $e;
-            if ( my $id = HTTPException->ident_for_status_code( $res->code ) ) {
+            try {
                 $e = HTTPException->new_exception(
-                    $id => {
+                    $res->code => {
                         additional_headers => [ $res->headers->flatten() ],
                         response           => $res,
                     }
                 );
             }
-            else {
+            catch {
                 $e = HTTPException->new_exception(
                     {
                         status_code        => $res->code,
@@ -165,8 +122,7 @@ use warnings;
                         response           => $res,
                     }
                 );
-            }
-
+            };
             for ($e) { $self->on_error->($e) }
         }
 
@@ -290,7 +246,7 @@ HTTP::Thin::UserAgent - A Thin UserAgent around some useful modules.
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 SYNOPSIS
 
@@ -353,11 +309,11 @@ Returns the decoded content, currently we only support HTML (in which case we re
 
 =item tree( )
 
-Returns a L<HTML::Treebuilder::XPath> object.
+Returns a L<HTML::TreeBuilder::XPath> object.
 
 =item find( $exp )
 
-Takes a CSS or XPath expression and returns an arrayref of L<HTML::Treebuilder::XPath> nodes.
+Takes a CSS or XPath expression and returns an arrayref of L<HTML::TreeBuilder::XPath> nodes.
 
 =item on_error( $coderef )
 
